from a10sdk.common.A10BaseClass import A10BaseClass


class CostCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param cost: {"description": "Interface cost", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param instance_id: {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "cost-cfg"
        self.DeviceProxy = ""
        self.cost = ""
        self.instance_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class HelloIntervalCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param hello_interval: {"description": "Time between HELLO packets (Seconds)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}
    :param instance_id: {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "hello-interval-cfg"
        self.DeviceProxy = ""
        self.hello_interval = ""
        self.instance_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class PriorityCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param priority: {"description": "Router priority", "format": "number", "default": 1, "maximum": 255, "minimum": 0, "type": "number"}
    :param instance_id: {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "priority-cfg"
        self.DeviceProxy = ""
        self.priority = ""
        self.instance_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class MtuIgnoreCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param mtu_ignore: {"default": 0, "type": "number", "description": "Ignores the MTU in DBD packets", "format": "flag"}
    :param instance_id: {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "mtu-ignore-cfg"
        self.DeviceProxy = ""
        self.mtu_ignore = ""
        self.instance_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class RetransmitIntervalCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param retransmit_interval: {"description": "Time between retransmitting lost link state advertisements (Seconds)", "format": "number", "default": 5, "maximum": 65535, "minimum": 1, "type": "number"}
    :param instance_id: {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "retransmit-interval-cfg"
        self.DeviceProxy = ""
        self.retransmit_interval = ""
        self.instance_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NetworkList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param broadcast_type: {"enum": ["broadcast", "non-broadcast", "point-to-point", "point-to-multipoint"], "type": "string", "description": "'broadcast': Specify OSPF broadcast multi-access network; 'non-broadcast': Specify OSPF NBMA network; 'point-to-point': Specify OSPF point-to-point network; 'point-to-multipoint': Specify OSPF point-to-multipoint network; ", "format": "enum"}
    :param p2mp_nbma: {"default": 0, "type": "number", "description": "Specify non-broadcast point-to-multipoint network", "format": "flag"}
    :param network_instance_id: {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "network-list"
        self.DeviceProxy = ""
        self.broadcast_type = ""
        self.p2mp_nbma = ""
        self.network_instance_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class TransmitDelayCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param transmit_delay: {"description": "Link state transmit delay (Seconds)", "format": "number", "default": 1, "maximum": 65535, "minimum": 1, "type": "number"}
    :param instance_id: {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "transmit-delay-cfg"
        self.DeviceProxy = ""
        self.transmit_delay = ""
        self.instance_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NeighborCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param neighbor_priority: {"description": "OSPF priority of non-broadcast neighbor", "minimum": 0, "type": "number", "maximum": 255, "format": "number"}
    :param neig_inst: {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}
    :param neighbor_poll_interval: {"description": "OSPF dead-router polling interval (Seconds)", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}
    :param neighbor_cost: {"description": "OSPF cost for point-to-multipoint neighbor (metric)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}
    :param neighbor: {"default": "::", "type": "string", "description": "OSPFv3 neighbor (Neighbor IPv6 address)", "format": "ipv6-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "neighbor-cfg"
        self.DeviceProxy = ""
        self.neighbor_priority = ""
        self.neig_inst = ""
        self.neighbor_poll_interval = ""
        self.neighbor_cost = ""
        self.neighbor = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DeadIntervalCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param dead_interval: {"description": "Interval after which a neighbor is declared dead (Seconds)", "format": "number", "default": 40, "maximum": 65535, "minimum": 1, "type": "number"}
    :param instance_id: {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "dead-interval-cfg"
        self.DeviceProxy = ""
        self.dead_interval = ""
        self.instance_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ospf(A10BaseClass):
    
    """Class Description::
    Open Shortest Path First for IPv6 (OSPFv3).

    Class ospf supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param bfd: {"default": 0, "optional": true, "type": "number", "description": "Bidirectional Forwarding Detection (BFD)", "format": "flag"}
    :param cost_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"cost": {"description": "Interface cost", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}
    :param hello_interval_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "hello-interval": {"description": "Time between HELLO packets (Seconds)", "format": "number", "default": 10, "maximum": 65535, "minimum": 1, "type": "number"}, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}
    :param disable: {"default": 0, "optional": true, "type": "number", "description": "Disable BFD", "format": "flag"}
    :param priority_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"priority": {"description": "Router priority", "format": "number", "default": 1, "maximum": 255, "minimum": 0, "type": "number"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}
    :param mtu_ignore_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"mtu-ignore": {"default": 0, "type": "number", "description": "Ignores the MTU in DBD packets", "format": "flag"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}
    :param retransmit_interval_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"retransmit-interval": {"description": "Time between retransmitting lost link state advertisements (Seconds)", "format": "number", "default": 5, "maximum": 65535, "minimum": 1, "type": "number"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}
    :param network_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"broadcast-type": {"enum": ["broadcast", "non-broadcast", "point-to-point", "point-to-multipoint"], "type": "string", "description": "'broadcast': Specify OSPF broadcast multi-access network; 'non-broadcast': Specify OSPF NBMA network; 'point-to-point': Specify OSPF point-to-point network; 'point-to-multipoint': Specify OSPF point-to-multipoint network; ", "format": "enum"}, "optional": true, "p2mp-nbma": {"default": 0, "type": "number", "description": "Specify non-broadcast point-to-multipoint network", "format": "flag"}, "network-instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}
    :param transmit_delay_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "transmit-delay": {"description": "Link state transmit delay (Seconds)", "format": "number", "default": 1, "maximum": 65535, "minimum": 1, "type": "number"}, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}
    :param neighbor_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"neighbor-priority": {"description": "OSPF priority of non-broadcast neighbor", "minimum": 0, "type": "number", "maximum": 255, "format": "number"}, "neig-inst": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}, "neighbor-poll-interval": {"description": "OSPF dead-router polling interval (Seconds)", "minimum": 0, "type": "number", "maximum": 4294967295, "format": "number"}, "neighbor-cost": {"description": "OSPF cost for point-to-multipoint neighbor (metric)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}, "neighbor": {"default": "::", "type": "string", "description": "OSPFv3 neighbor (Neighbor IPv6 address)", "format": "ipv6-address"}, "optional": true}}]}
    :param dead_interval_cfg: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"dead-interval": {"description": "Interval after which a neighbor is declared dead (Seconds)", "format": "number", "default": 40, "maximum": 65535, "minimum": 1, "type": "number"}, "optional": true, "instance-id": {"description": "Specify the interface instance ID", "format": "number", "default": 0, "maximum": 255, "minimum": 0, "type": "number"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/trunk/{ifnum}/ipv6/ospf`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ospf"
        self.a10_url="/axapi/v3/interface/trunk/{ifnum}/ipv6/ospf"
        self.DeviceProxy = ""
        self.bfd = ""
        self.cost_cfg = []
        self.hello_interval_cfg = []
        self.disable = ""
        self.priority_cfg = []
        self.mtu_ignore_cfg = []
        self.retransmit_interval_cfg = []
        self.network_list = []
        self.transmit_delay_cfg = []
        self.neighbor_cfg = []
        self.dead_interval_cfg = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SslCerts(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param status: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param name: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param notbefore: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param notafter: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param common_name: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param organization: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param serial: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param issuer: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param type: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param subject: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ssl-certs"
        self.DeviceProxy = ""
        self.status = ""
        self.name = ""
        self.notbefore = ""
        self.notafter = ""
        self.common_name = ""
        self.organization = ""
        self.serial = ""
        self.issuer = ""
        self.A10WW_type = ""
        self.subject = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ssl_certs: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"status": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "name": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "notbefore": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true, "notafter": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "common-name": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "organization": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "serial": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "issuer": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "type": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "subject": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.ssl_certs = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class SslCaCert(A10BaseClass):
    
    """Class Description::
    Operational Status for the object ssl-ca-cert.

    Class ssl-ca-cert supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/ssl-ca-cert/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ssl-ca-cert"
        self.a10_url="/axapi/v3/slb/ssl-ca-cert/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class VirtualServer(A10BaseClass):
    
    """Class Description::
    Virtual server template.

    Class virtual-server supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param conn_limit: {"description": "Connection limit", "format": "number", "type": "number", "maximum": 8000000, "minimum": 1, "optional": true}
    :param conn_rate_limit_no_logging: {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}
    :param name: {"description": "Virtual server template name", "format": "string", "default": "default", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param conn_limit_reset: {"default": 0, "optional": true, "type": "number", "description": "Send client reset when connection over limit", "format": "flag"}
    :param conn_rate_limit_reset: {"default": 0, "optional": true, "type": "number", "description": "Send client reset when connection rate over limit", "format": "flag"}
    :param rate_interval: {"description": "'100ms': Use 100 ms as sampling interval; 'second': Use 1 second as sampling interval; ", "format": "enum", "default": "second", "type": "string", "enum": ["100ms", "second"], "optional": true}
    :param icmpv6_rate_limit: {"description": "ICMPv6 rate limit (Normal rate limit. If exceeds this limit, drop the ICMP packet that goes over the limit)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param subnet_gratuitous_arp: {"default": 0, "optional": true, "type": "number", "description": "Send gratuitous ARP for every IP in the subnet virtual server", "format": "flag"}
    :param icmpv6_lockup: {"description": "Enter lockup state when ICMP rate exceeds lockup rate limit (Maximum rate limit. If exceeds this limit, drop all ICMP packet for a time period)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param conn_rate_limit: {"description": "Connection rate limit", "format": "number", "type": "number", "maximum": 1048575, "minimum": 1, "optional": true}
    :param icmp_lockup_period: {"description": "Lockup period (second)", "format": "number", "type": "number", "maximum": 16383, "minimum": 1, "optional": true}
    :param icmpv6_lockup_period: {"description": "Lockup period (second)", "format": "number", "type": "number", "maximum": 16383, "minimum": 1, "optional": true}
    :param conn_limit_no_logging: {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}
    :param icmp_rate_limit: {"description": "ICMP rate limit (Normal rate limit. If exceeds this limit, drop the ICMP packet that goes over the limit)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param icmp_lockup: {"description": "Enter lockup state when ICMP rate exceeds lockup rate limit (Maximum rate limit. If exceeds this limit, drop all ICMP packet for a time period)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/virtual-server/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "virtual-server"
        self.a10_url="/axapi/v3/slb/template/virtual-server/{name}"
        self.DeviceProxy = ""
        self.conn_limit = ""
        self.conn_rate_limit_no_logging = ""
        self.name = ""
        self.conn_limit_reset = ""
        self.conn_rate_limit_reset = ""
        self.rate_interval = ""
        self.icmpv6_rate_limit = ""
        self.subnet_gratuitous_arp = ""
        self.icmpv6_lockup = ""
        self.conn_rate_limit = ""
        self.icmp_lockup_period = ""
        self.icmpv6_lockup_period = ""
        self.conn_limit_no_logging = ""
        self.icmp_rate_limit = ""
        self.icmp_lockup = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class PortDiameter(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param svrsel_fail: {"description": "Number of server selection failed", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "2"}
    :param curr: {"description": "Current", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "2"}
    :param acr_out: {"description": "Number of ACRs out", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "2"}
    :param dwr_in: {"description": "Number of DWRs in", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "2"}
    :param num: {"description": "Number", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "2"}
    :param no_route: {"description": "Number of no routes", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "2"}
    :param server_fail: {"description": "Number of server failures", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "2"}
    :param user_session: {"description": "Number of user sessions", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "2"}
    :param aca_out: {"description": "Number of ACAs out", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "2"}
    :param sta_in: {"description": "Number of STAs in", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "2"}
    :param total: {"description": "Total", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "2"}
    :param dwa_in: {"description": "Number of DWAs in", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "2"}
    :param dwa_out: {"description": "Number of DWAs out", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "2"}
    :param asa_in: {"description": "Number of ASAs in", "format": "counter", "type": "number", "oid": "30", "optional": true, "size": "2"}
    :param asr_out: {"description": "Number of ASRs out", "format": "counter", "type": "number", "oid": "27", "optional": true, "size": "2"}
    :param aca_in: {"description": "Number of ACAs in", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "2"}
    :param dwr_out: {"description": "Number of DWRs out", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "2"}
    :param other_out: {"description": "Number of other messages out", "format": "counter", "type": "number", "oid": "31", "optional": true, "size": "2"}
    :param cea_out: {"description": "Number of CEAs out", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "2"}
    :param asr_in: {"description": "Number of ASRs in", "format": "counter", "type": "number", "oid": "28", "optional": true, "size": "2"}
    :param cer_in: {"description": "Number of CERs in", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "2"}
    :param str_in: {"description": "Number of STRs in", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "2"}
    :param sta_out: {"description": "Number of STAs out", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "2"}
    :param snat_fail: {"description": "Number of snat failures", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "2"}
    :param client_fail: {"description": "Number of client failures", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "2"}
    :param cer_out: {"description": "Number of CERs out", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "2"}
    :param str_out: {"description": "Number of STRs out", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "2"}
    :param cea_in: {"description": "Number of CEAs in", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "2"}
    :param asa_out: {"description": "Number of ASAs out", "format": "counter", "type": "number", "oid": "29", "optional": true, "size": "2"}
    :param no_sess: {"description": "Number of no sessions", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "2"}
    :param other_in: {"description": "Number of other messages in", "format": "counter", "type": "number", "oid": "32", "optional": true, "size": "2"}
    :param acr_in: {"description": "Number of ACRs in", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "2"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "port-diameter"
        self.DeviceProxy = ""
        self.svrsel_fail = ""
        self.curr = ""
        self.acr_out = ""
        self.dwr_in = ""
        self.num = ""
        self.no_route = ""
        self.server_fail = ""
        self.user_session = ""
        self.aca_out = ""
        self.sta_in = ""
        self.total = ""
        self.dwa_in = ""
        self.dwa_out = ""
        self.asa_in = ""
        self.asr_out = ""
        self.aca_in = ""
        self.dwr_out = ""
        self.other_out = ""
        self.cea_out = ""
        self.asr_in = ""
        self.cer_in = ""
        self.str_in = ""
        self.sta_out = ""
        self.snat_fail = ""
        self.client_fail = ""
        self.cer_out = ""
        self.str_out = ""
        self.cea_in = ""
        self.asa_out = ""
        self.no_sess = ""
        self.other_in = ""
        self.acr_in = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.port_diameter = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Port(A10BaseClass):
    
    """Class Description::
    Statistics for the object port-diameter.

    Class port supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/server/{name}/port/{port_number}+{protocol}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "port_number","protocol"]

        self.b_key = "port"
        self.a10_url="/axapi/v3/slb/server/{name}/port/{port_number}+{protocol}/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param radius_response_dropped: {"description": "Query Response Dropped", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param radius_requst_sent: {"description": "Query Request Sent", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param radius_requst_dropped: {"description": "Query Request Dropped", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param request_insert_client_ip_performed: {"description": "HTTP Client IP Insertion Performed", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param radius_query_succeed: {"description": "MSISDN Query Succeed", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param request_insert_msisdn_unavailable: {"description": "Inserted MSISDN is 0000 (MSISDN Unavailable)", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param request_processed: {"description": "HTTP Request Processed", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param request_insert_msisdn_performed: {"description": "HTTP MSISDN Insertion Performed", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param radius_query_failed: {"description": "MSISDN Query Failed", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param queued_session_too_many: {"description": "Queued Session Exceed Drop", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param radius_response_received: {"description": "Query Response Received", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.radius_response_dropped = ""
        self.radius_requst_sent = ""
        self.radius_requst_dropped = ""
        self.request_insert_client_ip_performed = ""
        self.radius_query_succeed = ""
        self.request_insert_msisdn_unavailable = ""
        self.request_processed = ""
        self.request_insert_msisdn_performed = ""
        self.radius_query_failed = ""
        self.queued_session_too_many = ""
        self.radius_response_received = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class HttpAlg(A10BaseClass):
    
    """Class Description::
    Statistics for the object http-alg.

    Class http-alg supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/http-alg/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "http-alg"
        self.a10_url="/axapi/v3/cgnv6/http-alg/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Limit(A10BaseClass):
    
    """Class Description::
    Specify limit for GSLB Message Protocol.

    Class limit supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ardt_response: {"description": "Response Messages of Active RDT, default is 1000 (Number)", "format": "number", "default": 1000, "optional": true, "maximum": 1000000, "minimum": 0, "type": "number"}
    :param conn_response: {"description": "Response Messages of Connection Load, default is no limit (Number)", "format": "number", "default": 0, "optional": true, "maximum": 1000000, "minimum": 0, "type": "number"}
    :param ardt_session: {"description": "Sessions of Active RDT, default is 32768 (Number)", "format": "number", "default": 32768, "optional": true, "maximum": 1000000, "minimum": 0, "type": "number"}
    :param ardt_query: {"description": "Query Messages of Active RDT, default is 200 (Number)", "format": "number", "default": 200, "optional": true, "maximum": 1000000, "minimum": 0, "type": "number"}
    :param message: {"description": "Amount of Messages, default is 10000 (Number)", "format": "number", "default": 10000, "optional": true, "maximum": 1000000, "minimum": 0, "type": "number"}
    :param response: {"description": "Amount of Response Messages, default is 3600 (Number)", "format": "number", "default": 3600, "optional": true, "maximum": 1000000, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/protocol/limit`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "limit"
        self.a10_url="/axapi/v3/gslb/protocol/limit"
        self.DeviceProxy = ""
        self.ardt_response = ""
        self.conn_response = ""
        self.ardt_session = ""
        self.ardt_query = ""
        self.message = ""
        self.response = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class TrunkMember(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param members: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "trunk-member"
        self.DeviceProxy = ""
        self.members = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Hardware: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param trunk_member: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "members": {"type": "number", "format": "number"}}}]}
    :param state: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param line_protocol: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param Address: {"minLength": 11, "maxLength": 17, "type": "string", "format": "mac-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.Hardware = ""
        self.trunk_member = []
        self.state = ""
        self.line_protocol = ""
        self.Address = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Router(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "router"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ospf(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ospf"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ip(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ip"
        self.DeviceProxy = ""
        self.oper = {}
        self.router = {}
        self.ospf = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Router(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "router"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv6(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ipv6"
        self.DeviceProxy = ""
        self.oper = {}
        self.router = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Trunk(A10BaseClass):
    
    """Class Description::
    Operational Status for the object trunk.

    Class trunk supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ifnum: {"optional": false, "oid": "1001", "type": "number", "description": "Trunk interface number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/trunk/{ifnum}/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "trunk"
        self.a10_url="/axapi/v3/interface/trunk/{ifnum}/oper"
        self.DeviceProxy = ""
        self.oper = {}
        self.ip = {}
        self.ifnum = ""
        self.ipv6 = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Ldap(A10BaseClass):
    
    """Class Description::
    LDAP Authentication Server.

    Class ldap supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param instance_list: {"minItems": 1, "items": {"type": "instance"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"health-check-string": {"description": "Health monitor name", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string", "$ref": "/axapi/v3/health/monitor"}, "port-hm": {"description": "Check port's health status", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "not": "port-hm-disable", "type": "string", "$ref": "/axapi/v3/health/monitor"}, "name": {"description": "Specify LDAP authentication server name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "port-hm-disable": {"description": "Disable configured port health check configuration", "format": "flag", "default": 0, "optional": true, "not": "port-hm", "type": "number"}, "admin-dn": {"description": "The LDAP server's admin DN", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}, "encrypted": {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED secret string)", "format": "encrypted"}, "default-domain": {"description": "Specify default domain for LDAP, cannot include \"\\\"", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "health-check-disable": {"description": "Disable configured health check configuration", "format": "flag", "default": 0, "optional": true, "not": "health-check", "type": "number"}, "admin-secret": {"default": 0, "optional": true, "type": "number", "description": "Specify the LDAP server's admin secret password", "format": "flag"}, "health-check": {"description": "Check server's health status", "format": "flag", "default": 0, "optional": true, "not": "health-check-disable", "type": "number"}, "bind-with-dn": {"default": 0, "optional": true, "type": "number", "description": "Enforce using DN for LDAP binding", "format": "flag"}, "host": {"type": "object", "properties": {"hostipv6": {"not": "hostip", "type": "string", "description": "Server's IPV6 address", "format": "ipv6-address"}, "hostip": {"description": "Server's hostname(Length 1-31) or IP address", "format": "host", "minLength": 1, "maxLength": 31, "not": "hostipv6", "type": "string"}}}, "base": {"description": "Specify the LDAP server's search base", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}, "dn-attribute": {"description": "Specify Distinguished Name attribute, default is CN", "format": "string-rlx", "default": "cn", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}, "timeout": {"description": "Specify timout for LDAP, default is 10 seconds (The timeout, default is 10 seconds)", "format": "number", "default": 10, "optional": true, "maximum": 255, "minimum": 1, "type": "number"}, "pwdmaxage": {"description": "Specify the LDAP server's default password expiration time (in seconds) (The LDAP server's default password expiration time (in seconds), default is 0 (no expiration))", "format": "number", "default": 0, "optional": true, "maximum": 4294967295, "minimum": 0, "type": "number"}, "derive-bind-dn": {"type": "object", "properties": {"username-attr": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Specify attribute name of username", "format": "string-rlx"}}}, "port": {"description": "Specify the LDAP server's authentication port, default is 389", "format": "number", "default": 389, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "secret-string": {"description": "secret password", "format": "password", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/aam/authentication/server/ldap/instance/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/server/ldap`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ldap"
        self.a10_url="/axapi/v3/aam/authentication/server/ldap"
        self.DeviceProxy = ""
        self.instance_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param min_jiffie: {"description": "Minimum number of jiffies", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param connect_failed: {"description": "Number of failed connections", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param num_burst: {"description": "Number of burst", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param ext_health_rate_val: {"description": "External health rate value", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "8"}
    :param retry_times: {"description": "Retry times", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "8"}
    :param send_packet: {"description": "Number of packets sent", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param status_other: {"description": "Number of other status", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "8"}
    :param unexpected_error: {"description": "Number of unexpected errors", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param status_down: {"description": "Number of status downs", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "8"}
    :param recv_packet_failed: {"description": "Number of failed packet receives", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "8"}
    :param close_socket: {"description": "Number of closed sockets", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param conn_imdt_succ: {"description": "Number of connection immediete success", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "8"}
    :param recv_packet: {"description": "Number of received packets", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param curr_health_rate: {"description": "Current health rate", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "8"}
    :param open_socket_failed: {"description": "Number of failed open sockets", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param send_packet_failed: {"description": "Number of packet send failures", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param sock_close_before_17: {"description": "Number of sockets closed before l7", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "8"}
    :param total_number: {"description": "Total number", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "8"}
    :param status_unkn: {"description": "Number of status unknowns", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "8"}
    :param open_socket: {"description": "Number of open sockets", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param sock_close_without_notify: {"description": "Number of sockets closed without notify", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "8"}
    :param status_up: {"description": "Number of status ups", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "8"}
    :param running_time: {"description": "Running time", "format": "counter", "type": "number", "oid": "27", "optional": true, "size": "8"}
    :param avg_jiffie: {"description": "Average number of jiffies", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param max_jiffie: {"description": "Maximum number of jiffies", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param ext_health_rate: {"description": "External health rate", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "8"}
    :param timeout: {"description": "Timouet value", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.min_jiffie = ""
        self.connect_failed = ""
        self.num_burst = ""
        self.ext_health_rate_val = ""
        self.retry_times = ""
        self.send_packet = ""
        self.status_other = ""
        self.unexpected_error = ""
        self.status_down = ""
        self.recv_packet_failed = ""
        self.close_socket = ""
        self.conn_imdt_succ = ""
        self.recv_packet = ""
        self.curr_health_rate = ""
        self.open_socket_failed = ""
        self.send_packet_failed = ""
        self.sock_close_before_17 = ""
        self.total_number = ""
        self.status_unkn = ""
        self.open_socket = ""
        self.sock_close_without_notify = ""
        self.status_up = ""
        self.running_time = ""
        self.avg_jiffie = ""
        self.max_jiffie = ""
        self.ext_health_rate = ""
        self.timeout = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class HealthStat(A10BaseClass):
    
    """Class Description::
    Statistics for the object health-stat.

    Class health-stat supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/health-stat/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "health-stat"
        self.a10_url="/axapi/v3/slb/health-stat/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class AddressList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param address_type: {"enum": ["anycast", "link-local"], "type": "string", "description": "'anycast': Configure an IPv6 anycast address; 'link-local': Configure an IPv6 link local address; ", "format": "enum"}
    :param ipv6_addr: {"type": "string", "description": "Set the IPv6 address of an interface", "format": "ipv6-address-plen"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "address-list"
        self.DeviceProxy = ""
        self.address_type = ""
        self.ipv6_addr = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class PrefixList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param not_autonomous: {"default": 0, "type": "number", "description": "Specify that the Prefix is not usable for autoconfiguration (default:autonomous)", "format": "flag"}
    :param valid_lifetime: {"description": "Specify Valid Lifetime (default:2592000) (Prefix Advertised Valid Lifetime (default: 2592000))", "format": "number", "default": 2592000, "maximum": 4294967295, "minimum": 0, "type": "number"}
    :param not_on_link: {"default": 0, "type": "number", "description": "Specify that the Prefix is not On-Link (default: on-link)", "format": "flag"}
    :param prefix: {"type": "string", "description": "Set Router Advertisement On-Link Prefix (IPv6 On-Link Prefix)", "format": "ipv6-address-plen"}
    :param preferred_lifetime: {"description": "Specify Prefix Preferred Lifetime (default:604800) (Prefix Advertised Preferred Lifetime (default: 604800))", "format": "number", "default": 604800, "maximum": 4294967295, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "prefix-list"
        self.DeviceProxy = ""
        self.not_autonomous = ""
        self.valid_lifetime = ""
        self.not_on_link = ""
        self.prefix = ""
        self.preferred_lifetime = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class RouterAdver(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param max_interval: {"description": "Set Router Advertisement Max Interval (default: 600) (Max Router Advertisement Interval (seconds))", "format": "number", "default": 600, "maximum": 1800, "minimum": 4, "type": "number"}
    :param default_lifetime: {"description": "Set Router Advertisement Default Lifetime (default: 1800) (Default Lifetime (seconds))", "format": "number", "default": 1800, "maximum": 9000, "minimum": 0, "type": "number"}
    :param ha_use_floating_ip: {"default": 0, "type": "number", "description": "Use a floating IP as the source address for Router advertisements", "format": "flag"}
    :param reachable_time: {"description": "Set Router Advertisement Reachable ime (default: 0) (Reachable Time (milliseconds))", "format": "number", "default": 0, "maximum": 3600000, "minimum": 0, "type": "number"}
    :param adver_ha_group_id: {"description": "HA Group ID", "minimum": 1, "type": "number", "maximum": 31, "format": "number"}
    :param ha_floating_ip: {"type": "string", "description": "Floating Point IPv6 address", "format": "ipv6-address"}
    :param prefix_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"not-autonomous": {"default": 0, "type": "number", "description": "Specify that the Prefix is not usable for autoconfiguration (default:autonomous)", "format": "flag"}, "valid-lifetime": {"description": "Specify Valid Lifetime (default:2592000) (Prefix Advertised Valid Lifetime (default: 2592000))", "format": "number", "default": 2592000, "maximum": 4294967295, "minimum": 0, "type": "number"}, "not-on-link": {"default": 0, "type": "number", "description": "Specify that the Prefix is not On-Link (default: on-link)", "format": "flag"}, "prefix": {"type": "string", "description": "Set Router Advertisement On-Link Prefix (IPv6 On-Link Prefix)", "format": "ipv6-address-plen"}, "preferred-lifetime": {"description": "Specify Prefix Preferred Lifetime (default:604800) (Prefix Advertised Preferred Lifetime (default: 604800))", "format": "number", "default": 604800, "maximum": 4294967295, "minimum": 0, "type": "number"}, "optional": true}}]}
    :param rate_limit: {"description": "Rate Limit the processing of incoming Router Solicitations (Max Number of Router Solicitations to process per second)", "format": "number", "default": 100000, "maximum": 100000, "minimum": 1, "type": "number"}
    :param adver_mtu_disable: {"default": 0, "not": "adver-mtu", "type": "number", "description": "Disable Router Advertisement MTU Option", "format": "flag"}
    :param min_interval: {"description": "Set Router Advertisement Min Interval (default: 200) (Min Router Advertisement Interval (seconds))", "format": "number", "default": 200, "maximum": 1350, "minimum": 3, "type": "number"}
    :param floating_ip: {"type": "string", "description": "Floating Point IPv6 address", "format": "ipv6-address"}
    :param adver_vrid: {"description": "Vrid", "format": "number", "maximum": 31, "minimum": 1, "not": "adver-vrid-default", "type": "number"}
    :param action: {"default": "enable", "enum": ["enable", "disable"], "type": "string", "description": "'enable': Enable Router Advertisements on this interface; 'disable': Disable Router Advertisements on this interface; ", "format": "enum"}
    :param adver_vrid_default: {"default": 0, "not": "adver-vrid", "type": "number", "description": "Default Value", "format": "flag"}
    :param adver_mtu: {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Set Router Advertisement MTU Option", "format": "number", "not": "adver-mtu-disable", "type": "number"}
    :param retransmit_timer: {"description": "Set Router Advertisement Retransmit Timer (default: 0)", "format": "number", "default": 0, "maximum": 4294967295, "minimum": 0, "type": "number"}
    :param hop_limit: {"description": "Set Router Advertisement Hop Limit (default: 255)", "format": "number", "default": 255, "maximum": 255, "minimum": 0, "type": "number"}
    :param use_floating_ip: {"default": 0, "type": "number", "description": "Use a floating IP as the source address for Router advertisements", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "router-adver"
        self.DeviceProxy = ""
        self.max_interval = ""
        self.default_lifetime = ""
        self.ha_use_floating_ip = ""
        self.reachable_time = ""
        self.adver_ha_group_id = ""
        self.ha_floating_ip = ""
        self.prefix_list = []
        self.rate_limit = ""
        self.adver_mtu_disable = ""
        self.min_interval = ""
        self.floating_ip = ""
        self.adver_vrid = ""
        self.action = ""
        self.adver_vrid_default = ""
        self.adver_mtu = ""
        self.retransmit_timer = ""
        self.hop_limit = ""
        self.use_floating_ip = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv6(A10BaseClass):
    
    """Class Description::
    Global IPv6 configuration subcommands.

    Class ipv6 supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param inbound: {"default": 0, "optional": true, "type": "number", "description": "ACL applied on incoming packets to this interface", "format": "flag"}
    :param address_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"address-type": {"enum": ["anycast", "link-local"], "type": "string", "description": "'anycast': Configure an IPv6 anycast address; 'link-local': Configure an IPv6 link local address; ", "format": "enum"}, "ipv6-addr": {"type": "string", "description": "Set the IPv6 address of an interface", "format": "ipv6-address-plen"}, "optional": true}}]}
    :param inside: {"default": 0, "optional": true, "type": "number", "description": "Configure interface as NAT inside", "format": "flag"}
    :param outside: {"default": 0, "optional": true, "type": "number", "description": "Configure interface as NAT outside", "format": "flag"}
    :param ipv6_enable: {"default": 0, "optional": true, "type": "number", "description": "Enable IPv6 processing", "format": "flag"}
    :param v6_acl_name: {"description": "Apply ACL rules to incoming packets on this interface (Named Access List)", "format": "string", "minLength": 1, "optional": true, "maxLength": 16, "type": "string", "$ref": "/axapi/v3/ipv6/access-list"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/ve/{ifnum}/ipv6`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ipv6"
        self.a10_url="/axapi/v3/interface/ve/{ifnum}/ipv6"
        self.DeviceProxy = ""
        self.inbound = ""
        self.address_list = []
        self.inside = ""
        self.outside = ""
        self.rip = {}
        self.ipv6_enable = ""
        self.stateful_firewall = {}
        self.v6_acl_name = ""
        self.router = {}
        self.ospf = {}
        self.router_adver = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class RangeListList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param global_start_ipv6_addr: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Global Start IPv6 Address of this list", "format": "ipv6-address-plen"}
    :param v4_vrid: {"description": "VRRP-A vrid (Specify ha VRRP-A vrid)", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "modify-not-allowed": 1, "type": "number"}
    :param global_netmaskv4: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Mask for this Address range", "format": "ipv4-netmask"}
    :param local_start_ipv6_addr: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Local Start IPv6 Address of this list", "format": "ipv6-address-plen"}
    :param local_netmaskv4: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Mask for this Address range", "format": "ipv4-netmask"}
    :param local_start_ipv4_addr: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Local Start IPv4 Address of this list", "format": "ipv4-address"}
    :param global_start_ipv4_addr: {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Global Start IPv4 Address of this list", "format": "ipv4-address"}
    :param v6_vrid: {"description": "VRRP-A vrid (Specify ha VRRP-A vrid)", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "modify-not-allowed": 1, "type": "number"}
    :param v4_count: {"description": "Number of addresses to be translated in this range", "format": "number", "optional": true, "maximum": 200000, "minimum": 1, "modify-not-allowed": 1, "type": "number"}
    :param v6_count: {"description": "Number of addresses to be translated in this range", "format": "number", "optional": true, "maximum": 200000, "minimum": 1, "modify-not-allowed": 1, "type": "number"}
    :param name: {"description": "Name for this Static List", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "range-list-list"
        self.DeviceProxy = ""
        self.global_start_ipv6_addr = ""
        self.v4_vrid = ""
        self.global_netmaskv4 = ""
        self.local_start_ipv6_addr = ""
        self.local_netmaskv4 = ""
        self.local_start_ipv4_addr = ""
        self.global_start_ipv4_addr = ""
        self.v6_vrid = ""
        self.v4_count = ""
        self.v6_count = ""
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Nat(A10BaseClass):
    
    """Class Description::
    Configure CGNv6 NAT.

    Class nat supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param range_list_list: {"minItems": 1, "items": {"type": "range-list"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"global-start-ipv6-addr": {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Global Start IPv6 Address of this list", "format": "ipv6-address-plen"}, "v4-vrid": {"description": "VRRP-A vrid (Specify ha VRRP-A vrid)", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "modify-not-allowed": 1, "type": "number"}, "global-netmaskv4": {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Mask for this Address range", "format": "ipv4-netmask"}, "local-start-ipv6-addr": {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Local Start IPv6 Address of this list", "format": "ipv6-address-plen"}, "local-netmaskv4": {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Mask for this Address range", "format": "ipv4-netmask"}, "local-start-ipv4-addr": {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Local Start IPv4 Address of this list", "format": "ipv4-address"}, "global-start-ipv4-addr": {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Global Start IPv4 Address of this list", "format": "ipv4-address"}, "v6-vrid": {"description": "VRRP-A vrid (Specify ha VRRP-A vrid)", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "modify-not-allowed": 1, "type": "number"}, "v4-count": {"description": "Number of addresses to be translated in this range", "format": "number", "optional": true, "maximum": 200000, "minimum": 1, "modify-not-allowed": 1, "type": "number"}, "v6-count": {"description": "Number of addresses to be translated in this range", "format": "number", "optional": true, "maximum": 200000, "minimum": 1, "modify-not-allowed": 1, "type": "number"}, "name": {"description": "Name for this Static List", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/nat/range-list/{name}"}
    :param pool_group_list: {"minItems": 1, "items": {"type": "pool-group"}, "uniqueItems": true, "array": [{"required": ["pool-group-name"], "properties": {"member-list": {"minItems": 1, "items": {"type": "member"}, "uniqueItems": true, "array": [{"required": ["pool-name"], "properties": {"pool-name": {"description": "Specify CGNv6 NAT pool name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/nat/pool-group/{pool-group-name}/member/{pool-name}"}, "pool-group-name": {"description": "Specify pool group name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "vrid": {"description": "Specify VRRP-A vrid", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "modify-not-allowed": 1, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/nat/pool-group/{pool-group-name}"}
    :param pool_list: {"minItems": 1, "items": {"type": "pool"}, "uniqueItems": true, "array": [{"required": ["pool-name"], "properties": {"max-users-per-ip": {"description": "Number of users that can be assigned to a NAT IP", "format": "number", "optional": true, "maximum": 64512, "minimum": 1, "modify-not-allowed": 1, "type": "number"}, "group": {"description": "Share with a partition group (Partition Group Name)", "format": "string", "minLength": 1, "modify-not-allowed": 1, "optional": true, "maxLength": 63, "type": "string"}, "start-address": {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Configure start IP address of NAT pool", "format": "ipv4-address"}, "vrid": {"description": "Configure VRRP-A vrid (Specify ha VRRP-A vrid)", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "modify-not-allowed": 1, "type": "number"}, "partition": {"description": "Share with a single partition (Partition Name)", "format": "string", "minLength": 1, "modify-not-allowed": 1, "optional": true, "maxLength": 14, "type": "string"}, "netmask": {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Configure mask for pool", "format": "ipv4-netmask-brief"}, "end-address": {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Configure end IP address of NAT pool", "format": "ipv4-address"}, "shared": {"description": "Share this pool with other partitions (default: not shared)", "partition-visibility": "shared", "default": 0, "optional": true, "format": "flag", "modify-not-allowed": 1, "type": "number"}, "exclude-ip": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"exclude-ip-start": {"type": "string", "description": "Single IP address or IP address range start", "format": "ipv4-address"}, "optional": true, "exclude-ip-end": {"type": "string", "description": "Address range end", "format": "ipv4-address"}}}]}, "pool-name": {"description": "Specify pool name or pool group", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/nat/pool/{pool-name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/nat`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "nat"
        self.a10_url="/axapi/v3/cgnv6/nat"
        self.DeviceProxy = ""
        self.range_list_list = []
        self.pool_group_list = []
        self.icmpv6 = {}
        self.icmp = {}
        self.inside = {}
        self.pool_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Template(A10BaseClass):
    
    """Class Description::
    Define a CGNv6 template.

    Class template supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param policy_list: {"minItems": 1, "items": {"type": "policy"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"name": {"description": "Policy template name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "class-list": {"type": "object", "properties": {"header-name": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify L7 header name", "format": "string"}, "client-ip-l7-header": {"default": 0, "not": "client-ip-l3-dest", "type": "number", "description": "Use extract client IP address from L7 header", "format": "flag"}, "client-ip-l3-dest": {"default": 0, "not": "client-ip-l7-header", "type": "number", "description": "Use destination IP as client IP address", "format": "flag"}, "lid-list": {"minItems": 1, "items": {"type": "lid"}, "uniqueItems": true, "array": [{"required": ["lidnum"], "properties": {"request-limit": {"description": "Request limit (Specify request limit)", "format": "number", "type": "number", "maximum": 1048575, "minimum": 0, "optional": true}, "conn-limit": {"description": "Connection limit", "format": "number", "type": "number", "maximum": 1048575, "minimum": 0, "optional": true}, "interval": {"description": "Specify log interval in minutes, by default system will log every over limit instance", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}, "log": {"default": 0, "optional": true, "type": "number", "description": "Log a message", "format": "flag"}, "dns64": {"type": "object", "properties": {"exclusive-answer": {"default": 0, "type": "number", "description": "Exclusive Answer in DNS Response", "format": "flag"}, "prefix": {"type": "string", "description": "IPv6 prefix", "format": "ipv6-address-plen"}, "disable": {"default": 0, "type": "number", "description": "Disable", "format": "flag"}}}, "lidnum": {"description": "Specify a limit ID", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": false}, "request-rate-limit": {"description": "Request rate limit (Specify request rate limit)", "format": "number", "type": "number", "maximum": 4294967295, "minimum": 1, "optional": true}, "conn-per": {"description": "Per (Specify interval in number of 100ms)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "request-per": {"description": "Per (Specify interval in number of 100ms)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "conn-rate-limit": {"description": "Specify connection rate limit", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 1, "optional": true}, "lockout": {"description": "Don't accept any new connection for certain time (Lockout duration in minutes)", "format": "number", "type": "number", "maximum": 1023, "minimum": 1, "optional": true}, "action-value": {"optional": true, "enum": ["forward", "reset"], "type": "string", "description": "'forward': Forward the traffic even it exceeds limit; 'reset': Reset the connection when it exceeds limit; ", "format": "enum"}, "over-limit-action": {"default": 0, "optional": true, "type": "number", "description": "Set action when exceeds limit", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/template/policy/{name}/class-list/lid/{lidnum}"}, "name": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Class list name", "format": "string-rlx"}}}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/template/policy/{name}"}
    :param logging_list: {"minItems": 1, "items": {"type": "logging"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"include-partition-name": {"default": 0, "optional": true, "type": "number", "description": "Include partition name in logging events", "format": "flag"}, "batched-logging-disable": {"default": 0, "optional": true, "type": "number", "description": "Disable multiple logs per packet", "format": "flag"}, "log-receiver": {"type": "object", "properties": {"encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED secret string)", "format": "encrypted"}, "radius": {"default": 0, "type": "number", "description": "Use RADIUS server for NAT logging", "format": "flag"}, "secret-string": {"minLength": 1, "maxLength": 127, "type": "string", "description": "The RADIUS server's secret", "format": "password"}}}, "name": {"description": "Logging template name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "include-inside-user-mac": {"default": 0, "optional": true, "type": "number", "description": "Include the inside user MAC address in logs", "format": "flag"}, "facility": {"description": "'kernel': 0: Kernel; 'user': 1: User-level; 'mail': 2: Mail; 'daemon': 3: System daemons; 'security-authorization': 4: Security/authorization; 'syslog': 5: Syslog internal; 'line-printer': 6: Line printer; 'news': 7: Network news; 'uucp': 8: UUCP subsystem; 'cron': 9: Time-related; 'security-authorization-private': 10: Private security/authorization; 'ftp': 11: FTP; 'ntp': 12: NTP; 'audit': 13: Audit; 'alert': 14: Alert; 'clock': 15: Clock-related; 'local0': 16: Local use 0; 'local1': 17: Local use 1; 'local2': 18: Local use 2; 'local3': 19: Local use 3; 'local4': 20: Local use 4; 'local5': 21: Local use 5; 'local6': 22: Local use 6; 'local7': 23: Local use 7; ", "format": "enum", "default": "local0", "type": "string", "enum": ["kernel", "user", "mail", "daemon", "security-authorization", "syslog", "line-printer", "news", "uucp", "cron", "security-authorization-private", "ftp", "ntp", "audit", "alert", "clock", "local0", "local1", "local2", "local3", "local4", "local5", "local6", "local7"], "optional": true}, "include-destination": {"default": 0, "optional": true, "type": "number", "description": "Include the destination IP and port in logs", "format": "flag"}, "severity": {"type": "object", "properties": {"severity-string": {"description": "'emergency': 0: Emergency; 'alert': 1: Alert; 'critical': 2: Critical; 'error': 3: Error; 'warning': 4: Warning; 'notice': 5: Notice; 'informational': 6: Informational; 'debug': 7: Debug; ", "format": "enum", "default": "debug", "enum": ["emergency", "alert", "critical", "error", "warning", "notice", "informational", "debug"], "not": "severity-val", "type": "string"}, "severity-val": {"description": "Logging severity level", "format": "number", "default": 7, "maximum": 7, "minimum": 0, "not": "severity-string", "type": "number"}}}, "format": {"description": "'binary': Binary logging format; 'compact': Compact ASCII logging format (Hex format with compact representation); 'custom': Arbitrary custom logging format; 'default': Default A10 logging format (ASCII); 'rfc5424': RFC5424 compliant logging format; ", "format": "enum", "default": "default", "type": "string", "enum": ["binary", "compact", "custom", "default", "rfc5424"], "optional": true}, "include-radius-attribute": {"type": "object", "properties": {"attr-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"attr-event": {"enum": ["http-requests", "port-mappings", "sessions"], "type": "string", "description": "'http-requests': Include in HTTP request logs; 'port-mappings': Include in port-mapping logs; 'sessions': Include in session logs; ", "format": "enum"}, "optional": true, "attr": {"enum": ["imei", "imsi", "msisdn", "custom1", "custom2", "custom3"], "type": "string", "description": "'imei': Include IMEI; 'imsi': Include IMSI; 'msisdn': Include MSISDN; 'custom1': Customized attribute 1; 'custom2': Customized attribute 2; 'custom3': Customized attribute 3; ", "format": "enum"}}}]}}}, "rule": {"type": "object", "properties": {"rule-http-requests": {"type": "object", "properties": {"log-every-http-request": {"default": 0, "type": "number", "description": "Log every HTTP request in an HTTP 1.1 session (Default: Log the first HTTP request in a session)", "format": "flag"}, "dest-port": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"include-byte-count": {"default": 0, "type": "number", "description": "Include the byte count of HTTP Request/Response in CGN session deletion logs", "format": "flag"}, "optional": true, "dest-port-number": {"minimum": 1, "type": "number", "maximum": 65535, "format": "number"}}}]}, "max-url-len": {"description": "Max length of URL log (Max URL length (Default: 100 char))", "format": "number", "default": 100, "maximum": 1000, "minimum": 100, "type": "number"}}}}}, "custom": {"type": "object", "properties": {"custom-header": {"enum": ["use-syslog-header"], "type": "string", "description": "'use-syslog-header': Use syslog header as custom log header; ", "format": "enum"}, "custom-message": {"type": "object", "properties": {"custom-http-request-got": {"minLength": 1, "maxLength": 255, "type": "string", "description": "HTTP request got (Custom message string)", "format": "string-rlx"}, "custom-fixed-nat-allocated": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Fixed-NAT allocated (Custom message string)", "format": "string-rlx"}, "custom-port-batch-freed": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Port Batch freed (Custom message string)", "format": "string-rlx"}, "custom-fixed-nat-freed": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Fixed-NAT freed (Custom message string)", "format": "string-rlx"}, "custom-port-batch-allocated": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Port Batch allocated (Custom message string)", "format": "string-rlx"}, "custom-port-allocated": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Port allocated (Custom message string)", "format": "string-rlx"}, "custom-session-deleted": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Session deleted (Custom message string)", "format": "string-rlx"}, "custom-port-freed": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Port freed (Custom message string)", "format": "string-rlx"}, "custom-session-created": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Session created (Custom message string)", "format": "string-rlx"}}}, "custom-time-stamp-format": {"minLength": 1, "maxLength": 31, "type": "string", "description": "Customize the time stamp format (Customize the time-stamp format. Default:%Y%m%d%H%M%S)", "format": "string-rlx"}}}, "service-group": {"description": "Set NAT logging service-group", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "rfc-custom": {"type": "object", "properties": {"header": {"type": "object", "properties": {"use-alternate-timestamp": {"default": 0, "type": "number", "description": "Use alternate non-RFC5424 compliant timestamp. Ex: 1990 Jan 15 12:30:30", "format": "flag"}}}, "message": {"type": "object", "properties": {"session-created": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Session created (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}, "http-request-got": {"minLength": 1, "maxLength": 255, "type": "string", "description": "HTTP request got (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}, "session-deleted": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Session deleted (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}, "ipv6-tech": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"fixed-nat-freed": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Fixed-NAT freed (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}, "port-batch-freed": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Port Batch freed (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}, "tech-type": {"enum": ["lsn", "nat64", "ds-lite", "sixrd-nat64"], "type": "string", "description": "'lsn': LSN; 'nat64': NAT64; 'ds-lite': DS-Lite; 'sixrd-nat64': 6rd-NAT64; ", "format": "enum"}, "fixed-nat-allocated": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Fixed-NAT allocated (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}, "port-allocated": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Port allocated (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}, "port-freed": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Port freed (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}, "optional": true, "port-batch-allocated": {"minLength": 1, "maxLength": 255, "type": "string", "description": "Port Batch allocated (Custom message string. Should be in the format of \"MSGID [STRUCTURED-DATA] MSG\")", "format": "string-rlx"}}}]}}}}}, "include-http": {"type": "object", "properties": {"header-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"custom-max-length": {"description": "Max length for a HTTP request log (Max header length (Default: 100 char))", "format": "number", "default": 100, "maximum": 1000, "minimum": 100, "type": "number"}, "http-header": {"enum": ["cookie", "referer", "user-agent", "header1", "header2", "header3"], "type": "string", "description": "'cookie': Log HTTP Cookie Header; 'referer': Log HTTP Referer Header; 'user-agent': Log HTTP User-Agent Header; 'header1': Log HTTP Header 1; 'header2': Log HTTP Header 2; 'header3': Log HTTP Header 3; ", "format": "enum"}, "optional": true, "custom-header-name": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Header name", "format": "string"}, "max-length": {"description": "Max length for a HTTP request log (Max header length (Default: 100 char))", "format": "number", "default": 100, "maximum": 1000, "minimum": 100, "type": "number"}}}]}, "request-number": {"default": 0, "type": "number", "description": "HTTP Request Number", "format": "flag"}, "method": {"default": 0, "type": "number", "description": "Log the HTTP Request Method", "format": "flag"}, "l4-session-info": {"default": 0, "type": "number", "description": "Log the L4 session information of the HTTP request", "format": "flag"}}}, "source-address": {"type": "object", "properties": {"ip": {"type": "string", "description": "Specify source IP address", "format": "ipv4-address"}, "ipv6": {"type": "string", "description": "Specify source IPv6 address", "format": "ipv6-address"}}}, "shared": {"description": "Service group is in shared patition", "partition-visibility": "private", "default": 0, "type": "number", "format": "flag", "optional": true}, "source-port": {"type": "object", "properties": {"source-port-num": {"description": "Set source port for sending NAT syslogs (default: 514)", "format": "number", "default": 514, "maximum": 65535, "minimum": 1, "not": "any", "type": "number"}, "any": {"default": 0, "not": "source-port-num", "type": "number", "description": "Use any source port", "format": "flag"}}}, "resolution": {"description": "'seconds': Logging timestamp resolution in seconds (default); '10-milliseconds': Logging timestamp resolution in 10s of milli-seconds; ", "format": "enum", "default": "seconds", "type": "string", "enum": ["seconds", "10-milliseconds"], "optional": true}, "log": {"type": "object", "properties": {"port-mappings": {"enum": ["creation", "disable"], "type": "string", "description": "'creation': Log only creation of NAT mappgins; 'disable': Disable Log creation and deletion of NAT mappings; ", "format": "enum"}, "port-overloading": {"default": 0, "type": "number", "description": "Force logging of all port-overloading sessions", "format": "flag"}, "fixed-nat": {"type": "object", "properties": {"user-ports": {"type": "object", "properties": {"start-time": {"type": "string", "description": "Time when periodic logging starts (Specify start time(hh:mm))", "format": "time-hhmm"}, "user-ports": {"default": 0, "type": "number", "description": "Log Fixed NAT User Ports Configured", "format": "flag"}, "days": {"description": "Specify period in days", "minimum": 1, "type": "number", "maximum": 30, "format": "number"}}}, "fixed-nat-http-requests": {"enum": ["host", "url"], "type": "string", "description": "'host': Log the HTTP Host Header; 'url': Log the HTTP Request URL; ", "format": "enum"}, "fixed-nat-sessions": {"default": 0, "type": "number", "description": "Log all Fixed NAT sessions", "format": "flag"}, "fixed-nat-port-mappings": {"enum": ["both", "creation"], "type": "string", "description": "'both': Log creation and deletion of NAT mappings; 'creation': Log creation of NAT mappings; ", "format": "enum"}}}, "http-requests": {"enum": ["host", "url"], "type": "string", "description": "'host': Log the HTTP Host Header; 'url': Log the HTTP Request URL; ", "format": "enum"}, "sessions": {"default": 0, "type": "number", "description": "Log all data sessions created using NAT", "format": "flag"}}}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/template/logging/{name}"}
    :param pcp_list: {"minItems": 1, "items": {"type": "pcp"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"source-ipv6": {"optional": true, "type": "string", "description": "Specify source IPv6 address for IPv6 ANNOUNCE message", "format": "ipv6-address"}, "allow-third-party-from-lan": {"default": 0, "optional": true, "type": "number", "description": "Allow third party request coming from LAN (default is disabled)", "format": "flag"}, "name": {"description": "PCP Template name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "map": {"default": 0, "optional": true, "type": "number", "description": "PCP MAP Opcode (default is enabled)", "format": "flag"}, "allow-third-party-from-wan": {"default": 0, "optional": true, "type": "number", "description": "Allow third party request coming from WAN (default is disabled)", "format": "flag"}, "maximum": {"description": "To set maximum lifetime of PCP mappings (default 1440 minutes)", "format": "number", "default": 1440, "optional": true, "maximum": 1440, "minimum": 2, "type": "number"}, "disable-map-filter": {"default": 0, "optional": true, "type": "number", "description": "To disable processing of FILTER options in MAP request", "format": "flag"}, "peer": {"default": 0, "optional": true, "type": "number", "description": "PCP PEER Opcode (default is enabled)", "format": "flag"}, "minimum": {"description": "To set minimum lifetime of PCP mappings (default 2 minutes)", "format": "number", "default": 2, "optional": true, "maximum": 1440, "minimum": 2, "type": "number"}, "check-client-nonce": {"default": 0, "optional": true, "type": "number", "description": "To validate NONCE value in PCP request (default: disabled)", "format": "flag"}, "announce": {"default": 0, "optional": true, "type": "number", "description": "PCP ANNOUNCE Opcode (default is enabled)", "format": "flag"}, "source-ip": {"optional": true, "type": "string", "description": "Specify source IP address for IPv4 ANNOUNCE message", "format": "ipv4-address"}, "pcp-server-port": {"description": "PCP server listening port (default 5351) (PCP UDP destination port)", "format": "number", "default": 5351, "optional": true, "maximum": 65535, "minimum": 1024, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/template/pcp/{name}"}
    :param http_alg_list: {"minItems": 1, "items": {"type": "http-alg"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"header-name-client-ip": {"description": "Header name (default: X-Forwarded-For)", "format": "string", "default": "X-Forwarded-For", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "retry": {"description": "Specify the maximum retries allowed for sending an request to a RADIUS server (default 2) (The maximum retries allowed for sending an request to the radius server (default 2))", "format": "number", "default": 2, "optional": true, "maximum": 3, "minimum": 0, "type": "number"}, "retry-svr-num": {"description": "Specify the maximum RADIUS servers allowed to try (default 0)", "format": "number", "default": 0, "optional": true, "maximum": 1, "minimum": 0, "type": "number"}, "name": {"description": "HTTP-ALG template name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "request-insert-msisdn": {"default": 0, "optional": true, "type": "number", "description": "Insert MSISDN into HTTP request", "format": "flag"}, "radius-sg": {"description": "RADIUS service group (RADIUS service group name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/cgnv6/service-group"}, "encrypted": {"optional": true, "type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED secret string)", "format": "encrypted"}, "request-insert-client-ip": {"default": 0, "optional": true, "type": "number", "description": "Insert Client IP into HTTP request", "format": "flag"}, "header-name-msisdn": {"description": "Header name (default: X-MSISDN)", "format": "string", "default": "X-MSISDN", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "timeout": {"description": "The maximum time allowed for waiting for a response from a radius server (default 2)", "format": "number", "default": 2, "optional": true, "maximum": 3, "minimum": 1, "type": "number"}, "include-tunnel-ip": {"default": 0, "optional": true, "type": "number", "description": "Include the tunnel IP (applies to DS-Lite and 6RD-NAT64 sessions)", "format": "flag"}, "method": {"description": "'append': Append if there is already a header (default); 'replace': Replace if there is already a header; ", "format": "enum", "default": "append", "type": "string", "enum": ["append", "replace"], "optional": true}, "secret-string": {"description": "The RADIUS secret", "format": "password", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/template/http-alg/{name}"}
    :param dns_list: {"minItems": 1, "items": {"type": "dns"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"name": {"description": "DNS Template Name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "class-list": {"type": "object", "properties": {"lid-list": {"minItems": 1, "items": {"type": "lid"}, "uniqueItems": true, "array": [{"required": ["lidnum"], "properties": {"over-limit-action": {"default": 0, "optional": true, "type": "number", "description": "Action when exceeds limit", "format": "flag"}, "log": {"default": 0, "optional": true, "type": "number", "description": "Log a message", "format": "flag"}, "lidnum": {"description": "Specify a limit ID", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": false}, "action-value": {"optional": true, "enum": ["dns-cache-disable", "dns-cache-enable", "forward"], "type": "string", "description": "'dns-cache-disable': Disable DNS cache when it exceeds limit; 'dns-cache-enable': Enable DNS cache when it exceeds limit; 'forward': Forward the traffic even it exceeds limit; ", "format": "enum"}, "per": {"description": "Per (Number of 100ms)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "lockout": {"description": "Don't accept any new connection for certain time (Lockout duration in minutes)", "format": "number", "type": "number", "maximum": 1023, "minimum": 1, "optional": true}, "dns": {"type": "object", "properties": {"cache-action": {"default": "cache-disable", "enum": ["cache-disable", "cache-enable"], "type": "string", "description": "'cache-disable': Disable dns cache; 'cache-enable': Enable dns cache; ", "format": "enum"}, "weight": {"description": "Weight for cache entry", "minimum": 1, "type": "number", "maximum": 7, "format": "number"}, "ttl": {"description": "TTL for cache entry (TTL in seconds)", "minimum": 1, "type": "number", "maximum": 65535, "format": "number"}}}, "conn-rate-limit": {"description": "Connection rate limit", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 1, "optional": true}, "log-interval": {"description": "Log interval (minute, by default system will log every over limit instance)", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/template/dns/{name}/class-list/lid/{lidnum}"}, "name": {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify a class list name", "format": "string-rlx"}}}, "dns64": {"type": "object", "properties": {"deep-check-rr-disable": {"default": 0, "type": "number", "description": "Disable Check DNS Response Records", "format": "flag"}, "answer-only-disable": {"default": 0, "type": "number", "description": "Disable Only translate the Answer Section", "format": "flag"}, "enable": {"default": 0, "type": "number", "description": "Enable DNS64 (Need to config this option before config any other dns64 options)", "format": "flag"}, "single-response-disable": {"default": 0, "type": "number", "description": "Disable Single Response which is used to avoid ambiguity", "format": "flag"}, "max-qr-length": {"description": "Max Question Record Length, default is 128", "format": "number", "default": 128, "maximum": 1023, "minimum": 1, "type": "number"}, "ignore-rcode3-disable": {"default": 0, "type": "number", "description": "Disable Ignore DNS error Response with rcode 3", "format": "flag"}, "ttl": {"description": "Specify Max TTL in DNS Response, unit: second", "minimum": 1, "type": "number", "maximum": 1000000000, "format": "number"}, "auth-data": {"default": 0, "type": "number", "description": "Set AA flag in DNS Response", "format": "flag"}, "change-query": {"default": 0, "type": "number", "description": "Always change incoming AAAA DNS Query to A", "format": "flag"}, "drop-cname-disable": {"default": 0, "type": "number", "description": "Disable Drop DNS CNAME Response", "format": "flag"}, "cache": {"default": 0, "type": "number", "description": "Generate Response by DNS Cache", "format": "flag"}, "passive-query-disable": {"default": 0, "type": "number", "description": "Disable Generate A query upon empty or error Response", "format": "flag"}, "retry": {"description": "Retry count, default is 3 (Retry Number)", "format": "number", "default": 3, "maximum": 15, "minimum": 0, "type": "number"}, "parallel-query": {"default": 0, "type": "number", "description": "Forward AAAA Query & generate A Query in parallel", "format": "flag"}, "timeout": {"description": "Timeout to send additional Queries, unit: second, default is 1", "format": "number", "default": 1, "maximum": 15, "minimum": 0, "type": "number"}, "compress-disable": {"default": 0, "type": "number", "description": "Disable Always try DNS Compression", "format": "flag"}, "trans-ptr-query": {"default": 0, "type": "number", "description": "Translate DNS PTR Query", "format": "flag"}, "trans-ptr": {"default": 0, "type": "number", "description": "Translate DNS PTR Records", "format": "flag"}}}, "drop": {"description": "Drop the malformed query", "format": "flag", "default": 0, "optional": true, "not": "forward", "type": "number"}, "period": {"description": "Period in minutes", "format": "number", "type": "number", "maximum": 10000, "minimum": 1, "optional": true}, "default-policy": {"optional": true, "enum": ["nocache", "cache"], "type": "string", "description": "'nocache': Cache disable; 'cache': Cache enable; ", "format": "enum"}, "max-cache-size": {"platform-specific-range": 1, "platform-specific-default": 1, "description": "Define maximum cache size (Maximum cache entry per VIP)", "format": "number", "optional": true, "type": "number"}, "forward": {"description": "Forward to service group (Service group name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 127, "not": "drop", "type": "string"}, "disable-dns-template": {"default": 0, "optional": true, "type": "number", "description": "Disable DNS template", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/template/dns/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/template`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "template"
        self.a10_url="/axapi/v3/cgnv6/template"
        self.DeviceProxy = ""
        self.policy_list = []
        self.logging_list = []
        self.pcp_list = []
        self.http_alg_list = []
        self.dns_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class PortResp(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param port_contains: {"minLength": 1, "maxLength": 127, "type": "string", "description": "Mark server up if response string contains another string (Specify the string)", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "port-resp"
        self.DeviceProxy = ""
        self.port_contains = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Tcp(A10BaseClass):
    
    """Class Description::
    TCP type.

    Class tcp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param port_send: {"description": "Send a string to server (Specify the string)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "not": "port-halfopen", "type": "string"}
    :param method_tcp: {"default": 0, "optional": true, "type": "number", "description": "TCP type", "format": "flag"}
    :param port_halfopen: {"description": "Set TCP SYN check", "format": "flag", "default": 0, "optional": true, "not": "port-send", "type": "number"}
    :param tcp_port: {"description": "Specify TCP port (Specify port number)", "format": "number", "type": "number", "maximum": 65534, "minimum": 1, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/health/monitor/{name}/method/tcp`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "tcp"
        self.a10_url="/axapi/v3/health/monitor/{name}/method/tcp"
        self.DeviceProxy = ""
        self.port_send = ""
        self.method_tcp = ""
        self.port_halfopen = ""
        self.port_resp = {}
        self.tcp_port = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Instance(A10BaseClass):
    
    """Class Description::
    Form-based Authentication Relay.

    Class instance supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"description": "Specify form-based authentication relay name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param request_uri_list: {"minItems": 1, "items": {"type": "request-uri"}, "uniqueItems": true, "array": [{"required": ["match-type", "uri"], "properties": {"other-variables": {"description": "Specify other variables (n1=v1&n2=v2) in form relay", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}, "action-uri": {"description": "Specify the action-URI", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}, "uri": {"description": "Specify request URI", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}, "cookie": {"type": "object", "properties": {"cookie-value": {"type": "object", "properties": {"cookie-value": {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify cookie in POST packet", "format": "string-rlx"}}}}}, "user-variable": {"description": "Specify username variable name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "domain-variable": {"description": "Specify domain variable name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "password-variable": {"description": "Specify password variable name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}, "match-type": {"optional": false, "enum": ["equals", "contains", "starts-with", "ends-with"], "type": "string", "description": "'equals': URI exactly matches the string; 'contains': URI string contains another sub string; 'starts-with': URI string starts with sub string; 'ends-with': URI string ends with sub string; ", "format": "enum"}}}], "type": "array", "$ref": "/axapi/v3/aam/authentication/relay/form-based/instance/{name}/request-uri/{match-type}+{uri}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/relay/form-based/instance/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "instance"
        self.a10_url="/axapi/v3/aam/authentication/relay/form-based/instance/{name}"
        self.DeviceProxy = ""
        self.name = ""
        self.request_uri_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class AclIdListList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param msl: {"description": "Maximum Session Life Value", "format": "number", "type": "number", "maximum": 1800, "minimum": 1, "optional": true}
    :param acl_id: {"description": "Acl id", "format": "number", "optional": false, "maximum": 199, "minimum": 1, "type": "number", "$ref": "/axapi/v3/access-list/standard"}
    :param pool: {"description": "Pool or Pool Group (Pool or Pool Group Name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/ip/nat/pool"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "acl-id-list-list"
        self.DeviceProxy = ""
        self.msl = ""
        self.acl_id = ""
        self.pool = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AclNameListList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param msl: {"description": "Maximum Session Life Value", "format": "number", "type": "number", "maximum": 1800, "minimum": 1, "optional": true}
    :param name: {"description": "Apply an access list", "format": "string", "minLength": 1, "optional": false, "maxLength": 16, "type": "string", "$ref": "/axapi/v3/ip/access-list"}
    :param pool: {"description": "Pool or Pool Group (Pool or Pool Group Nam)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/ip/nat/pool"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "acl-name-list-list"
        self.DeviceProxy = ""
        self.msl = ""
        self.name = ""
        self.pool = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class List(A10BaseClass):
    
    """Class Description::
    access-list-number.

    Class list supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param acl_id_list_list: {"minItems": 1, "items": {"type": "acl-id-list"}, "uniqueItems": true, "array": [{"required": ["acl-id"], "properties": {"msl": {"description": "Maximum Session Life Value", "format": "number", "type": "number", "maximum": 1800, "minimum": 1, "optional": true}, "acl-id": {"description": "Acl id", "format": "number", "optional": false, "maximum": 199, "minimum": 1, "type": "number", "$ref": "/axapi/v3/access-list/standard"}, "pool": {"description": "Pool or Pool Group (Pool or Pool Group Name)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/ip/nat/pool"}}}], "type": "array", "$ref": "/axapi/v3/ip/nat/inside/source/list/acl-id-list/{acl-id}"}
    :param acl_name_list_list: {"minItems": 1, "items": {"type": "acl-name-list"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"msl": {"description": "Maximum Session Life Value", "format": "number", "type": "number", "maximum": 1800, "minimum": 1, "optional": true}, "name": {"description": "Apply an access list", "format": "string", "minLength": 1, "optional": false, "maxLength": 16, "type": "string", "$ref": "/axapi/v3/ip/access-list"}, "pool": {"description": "Pool or Pool Group (Pool or Pool Group Nam)", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 128, "type": "string", "$ref": "/axapi/v3/ip/nat/pool"}}}], "type": "array", "$ref": "/axapi/v3/ip/nat/inside/source/list/acl-name-list/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/ip/nat/inside/source/list`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "list"
        self.a10_url="/axapi/v3/ip/nat/inside/source/list"
        self.DeviceProxy = ""
        self.acl_id_list_list = []
        self.acl_name_list_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param sync_rx_nat_create_sby: {"optional": true, "size": "8", "type": "number", "oid": "74", "format": "counter"}
    :param sync_rx_type_invalid: {"optional": true, "size": "8", "type": "number", "oid": "63", "format": "counter"}
    :param sync_persist_rx_no_such_sg_group: {"optional": true, "size": "8", "type": "number", "oid": "48", "format": "counter"}
    :param sync_rx_conn_exists: {"optional": true, "size": "8", "type": "number", "oid": "56", "format": "counter"}
    :param sync_get_buff_failed_port: {"optional": true, "size": "8", "type": "number", "oid": "72", "format": "counter"}
    :param err_port_counter: {"optional": true, "size": "8", "type": "number", "oid": "21", "format": "counter"}
    :param sync_tx_smp_radius_table_counter: {"optional": true, "size": "2", "type": "number", "oid": "17", "format": "counter"}
    :param err_parid_counter: {"optional": true, "size": "8", "type": "number", "oid": "23", "format": "counter"}
    :param sync_tx_total_info_counter: {"optional": true, "size": "8", "type": "number", "oid": "34", "format": "counter"}
    :param sync_rx_nat_alloc_sby: {"optional": true, "size": "8", "type": "number", "oid": "75", "format": "counter"}
    :param query_tx_min_packed: {"optional": true, "size": "2", "type": "number", "oid": "26", "format": "counter"}
    :param sync_rx_ext_bit_process_error: {"optional": true, "size": "8", "type": "number", "oid": "54", "format": "counter"}
    :param sync_rx_ext_nat_mac: {"optional": true, "size": "8", "type": "number", "oid": "86", "format": "counter"}
    :param sync_rx_lsn_fullcone: {"optional": true, "size": "8", "type": "number", "oid": "88", "format": "counter"}
    :param query_pkt_tx_counter: {"optional": true, "size": "2", "type": "number", "oid": "15", "format": "counter"}
    :param sync_rx_unk_counter: {"optional": true, "size": "8", "type": "number", "oid": "68", "format": "counter"}
    :param dup_id_rcv_counter: {"optional": true, "size": "8", "type": "number", "oid": "19", "format": "counter"}
    :param sync_tx_create_counter: {"optional": true, "size": "2", "type": "number", "oid": "6", "format": "counter"}
    :param sync_persist_rx_len_invalid: {"optional": true, "size": "8", "type": "number", "oid": "40", "format": "counter"}
    :param sync_rx_create_counter: {"optional": true, "size": "2", "type": "number", "oid": "3", "format": "counter"}
    :param err_devid_counter: {"optional": true, "size": "8", "type": "number", "oid": "24", "format": "counter"}
    :param sync_pkt_rcv_counter: {"optional": true, "size": "2", "type": "number", "oid": "2", "format": "counter"}
    :param sync_rx_len_invalid: {"optional": true, "size": "8", "type": "number", "oid": "39", "format": "counter"}
    :param sync_rx_ftp_control: {"optional": true, "size": "8", "type": "number", "oid": "83", "format": "counter"}
    :param sync_rx_persist_create_counter: {"optional": true, "size": "2", "type": "number", "oid": "9", "format": "counter"}
    :param sync_rx_ext_lsn_acl: {"optional": true, "size": "8", "type": "number", "oid": "84", "format": "counter"}
    :param sync_rx_ext_rtsp: {"optional": true, "size": "8", "type": "number", "oid": "80", "format": "counter"}
    :param sync_rx_update_seqnos_counter: {"optional": true, "size": "8", "type": "number", "oid": "67", "format": "counter"}
    :param sync_rx_conn_get_failed: {"optional": true, "size": "8", "type": "number", "oid": "57", "format": "counter"}
    :param sync_tx_persist_del_counter: {"optional": true, "size": "2", "type": "number", "oid": "13", "format": "counter"}
    :param sync_err_lsn_fullcone: {"optional": true, "size": "8", "type": "number", "oid": "89", "format": "counter"}
    :param sync_tx_del_counter: {"optional": true, "size": "2", "type": "number", "oid": "7", "format": "counter"}
    :param sync_tx_persist_update_age_counter: {"optional": true, "size": "2", "type": "number", "oid": "14", "format": "counter"}
    :param sync_persist_rx_vporttype_not_supported: {"optional": true, "size": "8", "type": "number", "oid": "46", "format": "counter"}
    :param sync_rx_dcmsg_counter: {"optional": true, "size": "8", "type": "number", "oid": "65", "format": "counter"}
    :param sync_rx_del_no_such_session: {"optional": true, "size": "8", "type": "number", "oid": "62", "format": "counter"}
    :param sync_tx_lsn_fullcone: {"optional": true, "size": "8", "type": "number", "oid": "87", "format": "counter"}
    :param sync_tx_persist_create_counter: {"optional": true, "size": "2", "type": "number", "oid": "12", "format": "counter"}
    :param sync_rx_smp_radius_table_counter: {"optional": true, "size": "2", "type": "number", "oid": "18", "format": "counter"}
    :param sync_tx_update_seqnos_counter: {"optional": true, "size": "8", "type": "number", "oid": "36", "format": "counter"}
    :param sync_rx_total_info_counter: {"optional": true, "size": "8", "type": "number", "oid": "66", "format": "counter"}
    :param sync_tx_get_buff_failed: {"optional": true, "size": "8", "type": "number", "oid": "33", "format": "counter"}
    :param sync_rx_create_ext_bit_counter: {"optional": true, "size": "8", "type": "number", "oid": "55", "format": "counter"}
    :param sync_rx_no_such_sg_node: {"optional": true, "size": "8", "type": "number", "oid": "61", "format": "counter"}
    :param sync_tx_update_age_counter: {"optional": true, "size": "2", "type": "number", "oid": "8", "format": "counter"}
    :param sync_rx_lsn_create_sby: {"optional": true, "size": "8", "type": "number", "oid": "73", "format": "counter"}
    :param sync_get_buff_failed_rt: {"optional": true, "size": "8", "type": "number", "oid": "71", "format": "counter"}
    :param sync_tx_create_ext_bit_counter: {"optional": true, "size": "8", "type": "number", "oid": "35", "format": "counter"}
    :param sync_tx_max_packed: {"optional": true, "size": "2", "type": "number", "oid": "38", "format": "counter"}
    :param sync_rx_persist_update_age_counter: {"optional": true, "size": "2", "type": "number", "oid": "11", "format": "counter"}
    :param sync_rx_sfw: {"optional": true, "size": "8", "type": "number", "oid": "77", "format": "counter"}
    :param sync_rx_seq_deltas: {"optional": true, "size": "8", "type": "number", "oid": "82", "format": "counter"}
    :param sync_rx_proto_not_supported: {"optional": true, "size": "8", "type": "number", "oid": "58", "format": "counter"}
    :param query_pkt_invalid_idx_counter: {"optional": true, "size": "8", "type": "number", "oid": "27", "format": "counter"}
    :param sync_rx_create_static_sby: {"optional": true, "size": "8", "type": "number", "oid": "78", "format": "counter"}
    :param sync_rx_persist_del_counter: {"optional": true, "size": "2", "type": "number", "oid": "10", "format": "counter"}
    :param sync_rx_update_age_counter: {"optional": true, "size": "2", "type": "number", "oid": "5", "format": "counter"}
    :param query_tx_max_packed: {"optional": true, "size": "2", "type": "number", "oid": "25", "format": "counter"}
    :param sync_persist_rx_ext_bit_process_error: {"optional": true, "size": "8", "type": "number", "oid": "44", "format": "counter"}
    :param query_pkt_rcv_counter: {"optional": true, "size": "2", "type": "number", "oid": "16", "format": "counter"}
    :param sync_rx_zero_info_counter: {"optional": true, "size": "8", "type": "number", "oid": "64", "format": "counter"}
    :param sync_pkt_tx_counter: {"optional": true, "size": "2", "type": "number", "oid": "1", "format": "counter"}
    :param sync_rx_ext_sip_alg: {"optional": true, "size": "8", "type": "number", "oid": "85", "format": "counter"}
    :param sync_rx_reserve_ha: {"optional": true, "size": "8", "type": "number", "oid": "81", "format": "counter"}
    :param vrrp_version_mismatch_counter: {"optional": true, "size": "8", "type": "number", "oid": "20", "format": "counter"}
    :param sync_rx_ext_pptp: {"optional": true, "size": "8", "type": "number", "oid": "79", "format": "counter"}
    :param sync_persist_rx_type_invalid: {"optional": true, "size": "8", "type": "number", "oid": "42", "format": "counter"}
    :param sync_rx_insert_tuple: {"optional": true, "size": "8", "type": "number", "oid": "76", "format": "counter"}
    :param sync_rx_no_such_nat_pool: {"optional": true, "size": "8", "type": "number", "oid": "60", "format": "counter"}
    :param sync_pkt_invalid_idx_counter: {"optional": true, "size": "8", "type": "number", "oid": "32", "format": "counter"}
    :param sync_rx_no_such_rport: {"optional": true, "size": "8", "type": "number", "oid": "52", "format": "counter"}
    :param sync_rx_apptype_not_supported: {"optional": true, "size": "8", "type": "number", "oid": "69", "format": "counter"}
    :param query_rx_zero_info_counter: {"optional": true, "size": "8", "type": "number", "oid": "29", "format": "counter"}
    :param sync_persist_rx_no_such_rport: {"optional": true, "size": "8", "type": "number", "oid": "47", "format": "counter"}
    :param sync_persist_rx_no_such_vport: {"optional": true, "size": "8", "type": "number", "oid": "45", "format": "counter"}
    :param query_tx_get_buff_failed: {"optional": true, "size": "8", "type": "number", "oid": "28", "format": "counter"}
    :param sync_persist_rx_cannot_process_mandatory: {"optional": true, "size": "8", "type": "number", "oid": "43", "format": "counter"}
    :param sync_persist_rx_proto_not_supported: {"optional": true, "size": "8", "type": "number", "oid": "41", "format": "counter"}
    :param sync_persist_rx_conn_get_failed: {"optional": true, "size": "8", "type": "number", "oid": "50", "format": "counter"}
    :param sync_rx_cannot_process_mandatory: {"optional": true, "size": "8", "type": "number", "oid": "53", "format": "counter"}
    :param sync_tx_min_packed: {"optional": true, "size": "2", "type": "number", "oid": "37", "format": "counter"}
    :param query_rx_unk_counter: {"optional": true, "size": "8", "type": "number", "oid": "31", "format": "counter"}
    :param sync_persist_rx_no_sg_group_info: {"optional": true, "size": "8", "type": "number", "oid": "49", "format": "counter"}
    :param sync_rx_no_such_vport: {"optional": true, "size": "8", "type": "number", "oid": "51", "format": "counter"}
    :param set_id_mismatch_counter: {"optional": true, "size": "8", "type": "number", "oid": "22", "format": "counter"}
    :param sync_rx_del_counter: {"optional": true, "size": "2", "type": "number", "oid": "4", "format": "counter"}
    :param query_rx_full_info_counter: {"optional": true, "size": "8", "type": "number", "oid": "30", "format": "counter"}
    :param sync_query_dcmsg_counter: {"optional": true, "size": "8", "type": "number", "oid": "70", "format": "counter"}
    :param sync_rx_no_dst_for_vport_inline: {"optional": true, "size": "8", "type": "number", "oid": "59", "format": "counter"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.sync_rx_nat_create_sby = ""
        self.sync_rx_type_invalid = ""
        self.sync_persist_rx_no_such_sg_group = ""
        self.sync_rx_conn_exists = ""
        self.sync_get_buff_failed_port = ""
        self.err_port_counter = ""
        self.sync_tx_smp_radius_table_counter = ""
        self.err_parid_counter = ""
        self.sync_tx_total_info_counter = ""
        self.sync_rx_nat_alloc_sby = ""
        self.query_tx_min_packed = ""
        self.sync_rx_ext_bit_process_error = ""
        self.sync_rx_ext_nat_mac = ""
        self.sync_rx_lsn_fullcone = ""
        self.query_pkt_tx_counter = ""
        self.sync_rx_unk_counter = ""
        self.dup_id_rcv_counter = ""
        self.sync_tx_create_counter = ""
        self.sync_persist_rx_len_invalid = ""
        self.sync_rx_create_counter = ""
        self.err_devid_counter = ""
        self.sync_pkt_rcv_counter = ""
        self.sync_rx_len_invalid = ""
        self.sync_rx_ftp_control = ""
        self.sync_rx_persist_create_counter = ""
        self.sync_rx_ext_lsn_acl = ""
        self.sync_rx_ext_rtsp = ""
        self.sync_rx_update_seqnos_counter = ""
        self.sync_rx_conn_get_failed = ""
        self.sync_tx_persist_del_counter = ""
        self.sync_err_lsn_fullcone = ""
        self.sync_tx_del_counter = ""
        self.sync_tx_persist_update_age_counter = ""
        self.sync_persist_rx_vporttype_not_supported = ""
        self.sync_rx_dcmsg_counter = ""
        self.sync_rx_del_no_such_session = ""
        self.sync_tx_lsn_fullcone = ""
        self.sync_tx_persist_create_counter = ""
        self.sync_rx_smp_radius_table_counter = ""
        self.sync_tx_update_seqnos_counter = ""
        self.sync_rx_total_info_counter = ""
        self.sync_tx_get_buff_failed = ""
        self.sync_rx_create_ext_bit_counter = ""
        self.sync_rx_no_such_sg_node = ""
        self.sync_tx_update_age_counter = ""
        self.sync_rx_lsn_create_sby = ""
        self.sync_get_buff_failed_rt = ""
        self.sync_tx_create_ext_bit_counter = ""
        self.sync_tx_max_packed = ""
        self.sync_rx_persist_update_age_counter = ""
        self.sync_rx_sfw = ""
        self.sync_rx_seq_deltas = ""
        self.sync_rx_proto_not_supported = ""
        self.query_pkt_invalid_idx_counter = ""
        self.sync_rx_create_static_sby = ""
        self.sync_rx_persist_del_counter = ""
        self.sync_rx_update_age_counter = ""
        self.query_tx_max_packed = ""
        self.sync_persist_rx_ext_bit_process_error = ""
        self.query_pkt_rcv_counter = ""
        self.sync_rx_zero_info_counter = ""
        self.sync_pkt_tx_counter = ""
        self.sync_rx_ext_sip_alg = ""
        self.sync_rx_reserve_ha = ""
        self.vrrp_version_mismatch_counter = ""
        self.sync_rx_ext_pptp = ""
        self.sync_persist_rx_type_invalid = ""
        self.sync_rx_insert_tuple = ""
        self.sync_rx_no_such_nat_pool = ""
        self.sync_pkt_invalid_idx_counter = ""
        self.sync_rx_no_such_rport = ""
        self.sync_rx_apptype_not_supported = ""
        self.query_rx_zero_info_counter = ""
        self.sync_persist_rx_no_such_rport = ""
        self.sync_persist_rx_no_such_vport = ""
        self.query_tx_get_buff_failed = ""
        self.sync_persist_rx_cannot_process_mandatory = ""
        self.sync_persist_rx_proto_not_supported = ""
        self.sync_persist_rx_conn_get_failed = ""
        self.sync_rx_cannot_process_mandatory = ""
        self.sync_tx_min_packed = ""
        self.query_rx_unk_counter = ""
        self.sync_persist_rx_no_sg_group_info = ""
        self.sync_rx_no_such_vport = ""
        self.set_id_mismatch_counter = ""
        self.sync_rx_del_counter = ""
        self.query_rx_full_info_counter = ""
        self.sync_query_dcmsg_counter = ""
        self.sync_rx_no_dst_for_vport_inline = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class State(A10BaseClass):
    
    """Class Description::
    Statistics for the object state.

    Class state supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vrrp-a/state/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "state"
        self.a10_url="/axapi/v3/vrrp-a/state/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Store(A10BaseClass):
    
    """    :param create: {"default": 0, "optional": true, "type": "number", "description": "Create an export store profile", "format": "flag"}
    :param name: {"description": "profile name to store remote url", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param remote_file: {"optional": true, "type": "string", "format": "url"}
    :param delete: {"default": 0, "optional": true, "type": "number", "description": "Delete an export store profile", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    Create store name for remote url.

    Class store supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/export/store`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "store"
        self.a10_url="/axapi/v3/export/store"
        self.DeviceProxy = ""
        self.create = ""
        self.name = ""
        self.remote_file = ""
        self.delete = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param udp_checksum_error: {"optional": true, "size": "2", "type": "number", "oid": "2", "format": "counter"}
    :param invalid_detect_mult: {"optional": true, "size": "2", "type": "number", "oid": "8", "format": "counter"}
    :param auth_length_invalid: {"optional": true, "size": "2", "type": "number", "oid": "12", "format": "counter"}
    :param auth_key_mismatch: {"optional": true, "size": "2", "type": "number", "oid": "16", "format": "counter"}
    :param invalid_my_disc: {"optional": true, "size": "2", "type": "number", "oid": "10", "format": "counter"}
    :param multihop_mismatch: {"optional": true, "size": "2", "type": "number", "oid": "4", "format": "counter"}
    :param dest_unreachable: {"optional": true, "size": "2", "type": "number", "oid": "20", "format": "counter"}
    :param length_too_small: {"optional": true, "size": "2", "type": "number", "oid": "6", "format": "counter"}
    :param auth_mismatch: {"optional": true, "size": "2", "type": "number", "oid": "13", "format": "counter"}
    :param auth_failed: {"optional": true, "size": "2", "type": "number", "oid": "18", "format": "counter"}
    :param auth_type_mismatch: {"optional": true, "size": "2", "type": "number", "oid": "14", "format": "counter"}
    :param invalid_ttl: {"optional": true, "size": "2", "type": "number", "oid": "11", "format": "counter"}
    :param data_is_short: {"optional": true, "size": "2", "type": "number", "oid": "7", "format": "counter"}
    :param session_not_found: {"optional": true, "size": "2", "type": "number", "oid": "3", "format": "counter"}
    :param auth_seqnum_invalid: {"optional": true, "size": "2", "type": "number", "oid": "17", "format": "counter"}
    :param local_state_admin_down: {"optional": true, "size": "2", "type": "number", "oid": "19", "format": "counter"}
    :param ip_checksum_error: {"optional": true, "size": "2", "type": "number", "oid": "1", "format": "counter"}
    :param version_mismatch: {"optional": true, "size": "2", "type": "number", "oid": "5", "format": "counter"}
    :param auth_key_id_mismatch: {"optional": true, "size": "2", "type": "number", "oid": "15", "format": "counter"}
    :param other_error: {"optional": true, "size": "2", "type": "number", "oid": "21", "format": "counter"}
    :param invalid_multipoint: {"optional": true, "size": "2", "type": "number", "oid": "9", "format": "counter"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.udp_checksum_error = ""
        self.invalid_detect_mult = ""
        self.auth_length_invalid = ""
        self.auth_key_mismatch = ""
        self.invalid_my_disc = ""
        self.multihop_mismatch = ""
        self.dest_unreachable = ""
        self.length_too_small = ""
        self.auth_mismatch = ""
        self.auth_failed = ""
        self.auth_type_mismatch = ""
        self.invalid_ttl = ""
        self.data_is_short = ""
        self.session_not_found = ""
        self.auth_seqnum_invalid = ""
        self.local_state_admin_down = ""
        self.ip_checksum_error = ""
        self.version_mismatch = ""
        self.auth_key_id_mismatch = ""
        self.other_error = ""
        self.invalid_multipoint = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Bfd(A10BaseClass):
    
    """Class Description::
    Statistics for the object bfd.

    Class bfd supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/system/bfd/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "bfd"
        self.a10_url="/axapi/v3/system/bfd/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class GeoLocnMultipleAddresses(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param first_ip_address: {"type": "string", "description": "Specify IP information (Specify IP address)", "format": "ipv4-address"}
    :param first_ipv6_address: {"type": "string", "description": "Specify IPv6 address", "format": "ipv6-address"}
    :param geol_ipv4_mask: {"not": "ip-addr2", "type": "string", "description": "Specify IPv4 mask", "format": "ipv4-netmask"}
    :param ip_addr2: {"not": "geol-ipv4-mask", "type": "string", "description": "Specify IP address range", "format": "ipv4-address"}
    :param ipv6_addr2: {"not": "geol-ipv6-mask", "type": "string", "description": "Specify IPv6 address range", "format": "ipv6-address"}
    :param geol_ipv6_mask: {"description": "Specify IPv6 mask", "format": "number", "maximum": 128, "minimum": 0, "not": "ipv6-addr2", "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "geo-locn-multiple-addresses"
        self.DeviceProxy = ""
        self.first_ip_address = ""
        self.first_ipv6_address = ""
        self.geol_ipv4_mask = ""
        self.ip_addr2 = ""
        self.ipv6_addr2 = ""
        self.geol_ipv6_mask = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class GeoLocation(A10BaseClass):
    
    """Class Description::
    Configure a GSLB global geo-location object.

    Class geo-location supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param geo_locn_obj_name: {"description": "Specify geo-location name, section range is (1-15)", "format": "string", "minLength": 1, "optional": false, "maxLength": 127, "type": "string"}
    :param geo_locn_multiple_addresses: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"first-ip-address": {"type": "string", "description": "Specify IP information (Specify IP address)", "format": "ipv4-address"}, "first-ipv6-address": {"type": "string", "description": "Specify IPv6 address", "format": "ipv6-address"}, "geol-ipv4-mask": {"not": "ip-addr2", "type": "string", "description": "Specify IPv4 mask", "format": "ipv4-netmask"}, "ip-addr2": {"not": "geol-ipv4-mask", "type": "string", "description": "Specify IP address range", "format": "ipv4-address"}, "ipv6-addr2": {"not": "geol-ipv6-mask", "type": "string", "description": "Specify IPv6 address range", "format": "ipv6-address"}, "geol-ipv6-mask": {"description": "Specify IPv6 mask", "format": "number", "maximum": 128, "minimum": 0, "not": "ipv6-addr2", "type": "number"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/geo-location/{geo_locn_obj_name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "geo_locn_obj_name"]

        self.b_key = "geo-location"
        self.a10_url="/axapi/v3/gslb/geo-location/{geo_locn_obj_name}"
        self.DeviceProxy = ""
        self.geo_locn_obj_name = ""
        self.geo_locn_multiple_addresses = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param rx_bad_inner_ipv4_len_pkts: {"description": "Packets received with Bad Inner IPv4 Payload length", "format": "counter", "type": "number", "oid": "34", "optional": true, "size": "2"}
    :param rx_pkts: {"description": "In Total Packets", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "8"}
    :param tx_encap_missing_pkts: {"description": "Remote Vtep unreachable: Drop Tx", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "2"}
    :param rx_mcast_pkts: {"description": "Out Multicast Packets", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "2"}
    :param cfg_vtep_error: {"description": "Config Error: Drop Packet", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "2"}
    :param rx_reassembled_pkts: {"description": "Reassembled Packets", "format": "counter", "type": "number", "oid": "33", "optional": true, "size": "2"}
    :param rx_ucast_pkts: {"description": "In Unicast Packets", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "8"}
    :param rx_lif_uninit: {"description": "Lif not UP: Drop Rx", "format": "counter", "type": "number", "oid": "36", "optional": true, "size": "2"}
    :param rx_lif_invalid: {"description": "Invalid Lif: Drop Rx", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "2"}
    :param rx_dot1q_ptks: {"description": "Dot1q Packet: Drop Rx", "format": "counter", "type": "number", "oid": "31", "optional": true, "size": "2"}
    :param rx_bad_checksum_pkts: {"description": "Packet reveived with Bad Inner checksum", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "2"}
    :param tx_bcast_pkts: {"description": "Out Broadcast Packets", "format": "counter", "type": "number", "oid": "27", "optional": true, "size": "8"}
    :param tx_fragmented_pkts: {"description": "Fragmented Packets", "format": "counter", "type": "number", "oid": "32", "optional": true, "size": "2"}
    :param rx_host_learned: {"description": "Number of Host =", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "2"}
    :param rx_unhandled_pkts: {"description": "Unhandled Packets: Drop Rx", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "2"}
    :param tx_arp_req_sent_pkts: {"description": "Number of Arp Requests Sent", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "2"}
    :param rx_host_learn_error: {"description": "Number of Host =", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "2"}
    :param rx_encap_miss_pkts: {"description": "Remote Vtep unreachable: Drop Tx", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "2"}
    :param rx_requeued_pkts: {"description": "Packets requeued to another CPU", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "2"}
    :param tx_lif_invalid: {"description": "Invalid Lif: Drop Tx", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "2"}
    :param rx_vtep_unknown: {"description": "Vtep unknown: Drop Rx", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "2"}
    :param rx_dropped_pkts: {"description": "In Dropped Packets", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "2"}
    :param tx_flood_pkts: {"description": "Out Flooded Packets", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param rx_bad_inner_ipv6_len_pkts: {"description": "Packets received with Bad Inner IPv6 Payload length", "format": "counter", "type": "number", "oid": "35", "optional": true, "size": "2"}
    :param rx_pkts_too_large: {"description": "Packet too large: Drop Rx", "format": "counter", "type": "number", "oid": "30", "optional": true, "size": "2"}
    :param tx_bytes: {"description": "Out Total Octets", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "8"}
    :param tx_mcast_pkts: {"description": "Out Multicast Packets", "format": "counter", "type": "number", "oid": "28", "optional": true, "size": "2"}
    :param tx_vtep_unknown: {"description": "Vtep unknown: Drop Tx", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "2"}
    :param tx_encap_unresolved_pkts: {"description": "Remote Vtep unreachable: Drop Tx", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "2"}
    :param tx_encap_bad_pkts: {"description": "Remote Vtep unreachable: Drop Tx", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "2"}
    :param rx_bcast_pkts: {"description": "In Broadcast Packets", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "8"}
    :param tx_unhandled_pkts: {"description": "Unhandled Packets: Drop Tx", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "2"}
    :param tx_dropped_pkts: {"description": "Out Dropped Packets", "format": "counter", "type": "number", "oid": "29", "optional": true, "size": "2"}
    :param tx_ucast_pkts: {"description": "Out Unicast Packets", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "8"}
    :param tx_pkts: {"description": "Out Total Packets", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "8"}
    :param rx_bytes: {"description": "In Total Octets", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.rx_bad_inner_ipv4_len_pkts = ""
        self.rx_pkts = ""
        self.tx_encap_missing_pkts = ""
        self.rx_mcast_pkts = ""
        self.cfg_vtep_error = ""
        self.rx_reassembled_pkts = ""
        self.rx_ucast_pkts = ""
        self.rx_lif_uninit = ""
        self.rx_lif_invalid = ""
        self.rx_dot1q_ptks = ""
        self.rx_bad_checksum_pkts = ""
        self.tx_bcast_pkts = ""
        self.tx_fragmented_pkts = ""
        self.rx_host_learned = ""
        self.rx_unhandled_pkts = ""
        self.tx_arp_req_sent_pkts = ""
        self.rx_host_learn_error = ""
        self.rx_encap_miss_pkts = ""
        self.rx_requeued_pkts = ""
        self.tx_lif_invalid = ""
        self.rx_vtep_unknown = ""
        self.rx_dropped_pkts = ""
        self.tx_flood_pkts = ""
        self.rx_bad_inner_ipv6_len_pkts = ""
        self.rx_pkts_too_large = ""
        self.tx_bytes = ""
        self.tx_mcast_pkts = ""
        self.tx_vtep_unknown = ""
        self.tx_encap_unresolved_pkts = ""
        self.tx_encap_bad_pkts = ""
        self.rx_bcast_pkts = ""
        self.tx_unhandled_pkts = ""
        self.tx_dropped_pkts = ""
        self.tx_ucast_pkts = ""
        self.tx_pkts = ""
        self.rx_bytes = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Vtep(A10BaseClass):
    
    """Class Description::
    Statistics for the object vtep.

    Class vtep supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/counter/vtep/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "vtep"
        self.a10_url="/axapi/v3/counter/vtep/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)


